@@ -46,10 +46,13 @@
 #' has not yet been calculated an error is returned.\cr\cr
 #' If \code{map = FALSE} and the input is a \code{CRTanalysis} object a plot of the
 #' estimated spillover function is generated. The fitted spillover function is plotted
-#' as a continuous blue line against the measure
+#' as a continuous green/blue line against the measure of
 #' the surround or of the distance to the nearest discordant location. Using the same axes, data summaries are plotted for
 #' ten categories of distance from the boundary. Both the
-#' average of the outcome and confidence intervals are plotted.
+#' average of the outcome and confidence intervals are plotted.If spillover limits have been estimated
+#' then these limits are used to delimit a shaded rectangular overlay, providing they fall within the range of distances
+#' in the data. If the spillover limits fall outside the range of the data then the range of distances in the data
+#' define the boundaries of the shaded area.
 #' \itemize{
 #' \item For analyses with logit link function the outcome is plotted as a proportion. \cr
 #' \item For analyses with log or cloglog link function the data are plotted on a scale of the Williams mean
@@ -68,8 +71,9 @@
 #' \item If the trial has not been randomised or if \code{showBuffer = FALSE} no buffer is displayed
 #' \item If \code{buffer_width} takes a positive value then buffers of this width are
 #' displayed irrespective of any pre-specified or spillover limits.
-#' \item If the input is a \code{'CRTanalysis'} and spillover limits have been estimated by
-#' an \code{'LME4'} or \code{'INLA'} model then these limits are used to define the displayed buffer.
+#' \item If the input is a \code{'CRTanalysis'} and spillover limits have been estimated
+#' then these limits are used to define the displayed buffer providing they fall within the range of distances
+#' in the data.
 #' \item If \code{buffer_width} is not specified and no spillover limits are available, then any
 #' pre-specified buffer (e.g. one generated by \code{specify_buffer()}) is displayed.
 #' }
@@ -102,7 +106,8 @@ plotCRT <- function(object, map = FALSE, distance = "nearestDiscord", fill = "ar
     cpalette = NULL, buffer_width = NULL, maskbuffer = 0.2, labelsize = 4,
     legend.position = NULL) {
 
-    control_curve <- intervention_curve <- scale_par <- buffer <- g <- NULL
+    spillover_limits <- control_curve <- intervention_curve <- NULL
+    scale_par <- buffer <- g <- NULL
     if (is.null(legend.position)) legend.position <- "none"
     if (!isa(object, what = 'CRTanalysis')) object <- CRTsp(object)
     trial <- object$trial
@@ -120,41 +125,53 @@ plotCRT <- function(object, map = FALSE, distance = "nearestDiscord", fill = "ar
         if (isa(object, what = 'CRTanalysis')) {
             # if the object is the output from analysisCRT
             analysis <- object
-            if (is.null(analysis$spillover$FittedCurve))
-                stop("*** No fitted curve available ***")
             d <- average <- upper <- lower <- spilloverFunction <- NULL
-            interval <- analysis$spillover$spillover_limits
-            range <- max(analysis$trial[[distance]]) - min(analysis$trial[[distance]])
             data <- group_data(analysis = analysis, grouping = "quintiles")
-            FittedCurve <- analysis$spillover$FittedCurve
-            fitted_median <- median(c(FittedCurve$control_curve,FittedCurve$intervention_curve),na.rm = TRUE)
+            range <- quantile(analysis$trial[[distance]], 0.975) - quantile(analysis$trial[[distance]], 0.025)
             data_median <- median(data$average)
-            if (analysis$options$link %in% c('log', 'cloglog')) {
-                scale_factor <- fitted_median/data_median
-                data_scaled <- data.frame(
-                                    d = data$d,
-                                    arm = data$arm,
-                                    average = data$average * scale_factor,
-                                    lower = data$lower * scale_factor,
-                                    upper = data$upper * scale_factor)
-            } else {
-                data_scaled <- data
-            }
+            data_scaled <- data #To be overwritten in the case of a log link and fitted spillover
+            X2.5. <- X97.5. <- NULL
             g <- ggplot2::ggplot() + ggplot2::theme_bw()
-            g <- g + ggplot2::geom_line(data = FittedCurve[!is.na(FittedCurve$control_curve), ],
+            if (is.null(analysis$spillover$FittedCurve)) {
+                warning("*** No fitted curve available ***")
+            } else {
+                interval <- analysis$spillover$spillover_limits
+                interval[1] <- max(min(analysis$trial[[distance]]), interval[1])
+                interval[2] <- min(max(analysis$trial[[distance]]), interval[2])
+                FittedCurve <- analysis$spillover$FittedCurve
+                FittedCurve <- FittedCurve[FittedCurve$d >= min(c(interval[1], data$d))
+                                           & FittedCurve$d <= max(c(interval[2], data$d)), ]
+                fitted_median <- median(c(FittedCurve$control_curve,FittedCurve$intervention_curve),na.rm = TRUE)
+                if (analysis$options$link %in% c('log', 'cloglog')) {
+                    scale_factor <- fitted_median/data_median
+                    data_scaled <- data.frame(
+                        d = data$d,
+                        arm = data$arm,
+                        average = data$average * scale_factor,
+                        lower = data$lower * scale_factor,
+                        upper = data$upper * scale_factor)
+                }
+                g <- g + ggplot2::geom_line(data = FittedCurve[!is.na(FittedCurve$control_curve), ],
                             ggplot2::aes(x = d, y = control_curve), linewidth = 2, colour = "#b2df8a")
-            g <- g + ggplot2::geom_line(data = FittedCurve[!is.na(FittedCurve$intervention_curve), ],
+                g <- g + ggplot2::geom_line(data = FittedCurve[!is.na(FittedCurve$intervention_curve), ],
                             ggplot2::aes(x = d, y = intervention_curve), linewidth = 2, colour = "#0072A7")
+
+                if (!is.null(FittedCurve$X2.5.)) {
+                    g <- g + ggplot2::geom_ribbon(data = FittedCurve,
+                         ggplot2::aes(x = d, ymin = X2.5., ymax = X97.5.),
+                         fill = "pink", alpha = 0.4, linetype = 0)
+                }
+            }
             g <- g + ggplot2::geom_point(data = data_scaled, ggplot2::aes(x = d, y = average,
                                         shape=factor(arm)), size = 2)
             g <- g + ggplot2::scale_shape_manual(name = "Arms", values = c(0, 16),
-                                                 labels = c("Control", "Intervention"))
+                                         labels = c("Control", "Intervention"))
             g <- g + ggplot2::theme(legend.position = legend.position)
             g <- g + ggplot2::geom_errorbar(data = data_scaled, mapping = ggplot2::aes(x = d, ymin = upper,
                                         ymax = lower), linewidth = 0.5, width = range/50)
             if (identical(analysis$options$distance, "nearestDiscord")) {
                 g <- g + ggplot2::geom_vline(xintercept = 0, linewidth = 1, linetype = "dashed")
-                if (analysis$options$cfunc %in% c("L","P","S")) {
+                if (analysis$options$cfunc %in% c("L","P","S", "D")) {
                     g <- g + ggplot2::geom_vline(xintercept = interval, linewidth = 1)
                     g <- g + ggplot2::geom_rect(data = NULL, ggplot2::aes(xmin = interval[1], xmax = interval[2],
                                                  ymin = -Inf, ymax = Inf), fill = alpha("#2C77BF", 0.2))
@@ -183,7 +200,7 @@ plotCRT <- function(object, map = FALSE, distance = "nearestDiscord", fill = "ar
                 ggplot2::geom_bar(aes(x = dcat, y = value), colour = NA, fill = "lightgrey", stat = "identity") +
                 ggplot2::geom_vline(xintercept = 0, linewidth = 1, linetype = "dashed") +
                 ggplot2::xlab(distanceText) +
-                ggplot2::ylab(ggplot2::element_blank()) +
+                ggplot2::ylab("") +
                 ggplot2::facet_wrap( ~ variable, ncol = 1, scales = "free")
 
         }
